==> archive-5.2.4-sources.jar: com/gtis/archive/entity/Archive.java <==
package com.gtis.archive.entity;

import org.apache.commons.lang.StringUtils;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import javax.persistence.*;
import java.util.Date;

/**
 * 档案
 * <p/>
 * Generated 2010-08-13 13:15:25 by Model Code Generater 1.0
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 */
@Entity
@Table(name = "t_archive")
@Inheritance(strategy = InheritanceType.JOINED)
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Archive {
    public static final String MODEL_NAME = Archive.class.getSimpleName();
    public static final String DOCUMENT_SUFFIX = "_jn";
    public static final int STATE_WGD = 0;
    public static final int STATE_YGD = 1;

    @Id
    @Column(length = 32)
    private String id;

    /**
     * 模型名
     */
    @Column(length = 10)
    private String modelName = getClass().getSimpleName();

    /**
     * 档号
     */
    @Column(length = 100)
    private String dh;

    /**
     * 单位代码
     */
    @Column(length = 100, nullable = false)
    private String dwdm;

    /**
     * 全宗号
     */
    @Column(length = 100, nullable = false)
    private String qzh;

    /**
     * 目录号
     */
    @Column(length = 100)
    private String mlh;

    /**
     * 案卷号
     */
    @Column
    private Integer ajh;

    /**
     * 题名
     */
    @Column(length = 1000)
    private String tm;

    /**
     * 分类号
     */
    @Column(length = 100)
    private String flh;

    /**
     * 年度
     */
    @Column(length = 10)
    private String nd;

    /**
     * 起日期
     */
    private Date qrq;

    /**
     * 止日期
     */
    private Date zrq;

    /**
     * 件数
     */
    @Column
    private Integer js;

    /**
     * 页数
     */
    @Column
    private Integer ys;

    /**
     * 保管期限
     */
    @Column(length = 10, nullable = false)
    private String bgqx;

    /**
     * 密级
     */
    @Column(length = 10, nullable = false)
    private String mj;

    /**
     * 箱号
     */
    @Column(length = 100)
    private String xh;

    /**
     * 存放位置
     */
    @Column(length = 100)
    private String cfwz;

    /**
     * 备注
     */
    @Column(length = 1000)
    private String bz;

    /**
     * 归档时间
     */
    private Date gdsj;

    /**
     * 资源序号
     */
    @Column(length = 100)
    private String resourceId;

    /**
     * 状态，已归档，未归档
     */
    @Column
    private int state;

    /**
     * 文本格式的起日期
     */
    private String sqrq;


    /**
     * 文本格式的止日期
     */
    private String szrq;

    /**
     * 是否存在原文
     */
    @Transient
    private Boolean hasOriginal;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getModelName() {
        return modelName;
    }

    public void setModelName(String modelName) {
        if (StringUtils.isNotEmpty(modelName))
            this.modelName = modelName;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQzh() {
        return qzh;
    }

    public void setQzh(String qzh) {
        this.qzh = qzh;
    }

    public String getMlh() {
        return mlh;
    }

    public void setMlh(String mlh) {
        this.mlh = mlh;
    }

    public Integer getAjh() {
        return ajh;
    }

    public void setAjh(Integer ajh) {
        this.ajh = ajh;
    }

    public String getTm() {
        return tm;
    }

    public void setTm(String tm) {
        this.tm = tm;
    }

    public String getFlh() {
        return flh;
    }

    public void setFlh(String flh) {
        this.flh = flh;
    }

    public String getNd() {
        return nd;
    }

    public void setNd(String nd) {
        this.nd = nd;
    }

    public Date getQrq() {
        return qrq;
    }

    public void setQrq(Date qrq) {
        this.qrq = qrq;
    }

    public Date getZrq() {
        return zrq;
    }

    public void setZrq(Date zrq) {
        this.zrq = zrq;
    }

    public Integer getJs() {
        return js;
    }

    public void setJs(Integer js) {
        this.js = js;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }

    public String getBgqx() {
        return bgqx;
    }

    public void setBgqx(String bgqx) {
        this.bgqx = StringUtils.trim(bgqx);
    }

    public String getMj() {
        return mj;
    }

    public void setMj(String mj) {
        this.mj = StringUtils.trim(mj);
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getCfwz() {
        return cfwz;
    }

    public void setCfwz(String cfwz) {
        this.cfwz = cfwz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getGdsj() {
        return gdsj;
    }

    public void setGdsj(Date gdsj) {
        this.gdsj = gdsj;
    }

    public String getResourceId() {
        return resourceId;
    }

    public void setResourceId(String resourceId) {
        this.resourceId = resourceId;
    }

    public int getState() {
        return state;
    }

    public void setState(int state) {
        this.state = state;
    }

    public String getSqrq() {
        return sqrq;
    }

    public void setSqrq(String sqrq) {
        this.sqrq = sqrq;
    }

    public String getSzrq() {
        return szrq;
    }

    public void setSzrq(String szrq) {
        this.szrq = szrq;
    }

    public Boolean getHasOriginal() {
        return hasOriginal;
    }

    public void setHasOriginal(Boolean hasOriginal) {
        this.hasOriginal = hasOriginal;
    }

    public static boolean isArchiveModelName(String modelName) {
        return !modelName.endsWith(Archive.DOCUMENT_SUFFIX) && !Document.MODEL_NAME.endsWith(modelName);
    }

    public static String toDocumentModelName(String archiveModelName) {
        if (archiveModelName.endsWith(Archive.DOCUMENT_SUFFIX)) {
            return archiveModelName;
        } else if (Archive.MODEL_NAME.equals(archiveModelName) || Document.MODEL_NAME.equals(archiveModelName)) {
            return Document.MODEL_NAME;
        } else {
            return archiveModelName + Archive.DOCUMENT_SUFFIX;
        }
    }
}

==> archive-5.4.3-sources.jar: com/gtis/archive/entity/Archive.java <==
package com.gtis.archive.entity;

import org.apache.commons.lang.StringUtils;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import javax.persistence.*;
import java.util.Date;

/**
 * 档案
 * <p/>
 * Generated 2010-08-13 13:15:25 by Model Code Generater 1.0
 * <p/>
 *
 * @author <a href="mailto:oxsean@gmail.com">sean yang</a>
 */
@Entity
@Table(name = "t_archive")
@Inheritance(strategy = InheritanceType.JOINED)
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Archive {
    public static final String MODEL_NAME = Archive.class.getSimpleName();
    public static final String DOCUMENT_SUFFIX = "_jn";
    public static final int STATE_WGD = 0;
    public static final int STATE_YGD = 1;

    @Id
    @Column(length = 32)
    private String id;

    /**
     * 模型名
     */
    @Column(length = 10)
    private String modelName = getClass().getSimpleName();

    /**
     * 档号
     */
    @Column(length = 100)
    private String dh;

    /**
     * 单位代码
     */
    @Column(length = 100, nullable = true)
    private String dwdm;

    /**
     * 全宗号
     */
    @Column(length = 100, nullable = true)
    private String qzh;

    /**
     * 目录号
     */
    @Column(length = 100)
    private String mlh;

    /**
     * 案卷号
     */
    @Column
    private Integer ajh;

    /**
     * 题名
     */
    @Column(length = 1000)
    private String tm;

    /**
     * 分类号
     */
    @Column(length = 100)
    private String flh;

    /**
     * 年度
     */
    @Column(length = 10)
    private String nd;

    /**
     * 起日期
     */
    private Date qrq;

    /**
     * 止日期
     */
    private Date zrq;

    /**
     * 件数
     */
    @Column
    private Integer js;

    /**
     * 页数
     */
    @Column
    private Integer ys;

    /**
     * 保管期限
     */
    @Column(length = 10, nullable = false)
    private String bgqx;

    /**
     * 密级
     */
    @Column(length = 10, nullable = false)
    private String mj;

    /**
     * 箱号
     */
    @Column(length = 100)
    private String xh;

    /**
     * 存放位置
     */
    @Column(length = 100)
    private String cfwz;

    /**
     * 备注
     */
    @Column(length = 1000)
    private String bz;

    /**
     * 归档时间
     */
    private Date gdsj;

    /**
     * 资源序号
     */
    @Column(length = 100)
    private String resourceId;

    /**
     * 状态，已归档，未归档
     */
    @Column
    private int state;

    /**
     * 文本格式的起日期
     */
    private String sqrq;


    /**
     * 文本格式的止日期
     */
    private String szrq;

    /**
     * 是否存在原文
     */
    @Transient
    private Boolean hasOriginal;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getModelName() {
        return modelName;
    }

    public void setModelName(String modelName) {
        if (StringUtils.isNotEmpty(modelName))
            this.modelName = modelName;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQzh() {
        return qzh;
    }

    public void setQzh(String qzh) {
        this.qzh = qzh;
    }

    public String getMlh() {
        return mlh;
    }

    public void setMlh(String mlh) {
        this.mlh = mlh;
    }

    public Integer getAjh() {
        return ajh;
    }

    public void setAjh(Integer ajh) {
        this.ajh = ajh;
    }

    public String getTm() {
        return tm;
    }

    public void setTm(String tm) {
        this.tm = tm;
    }

    public String getFlh() {
        return flh;
    }

    public void setFlh(String flh) {
        this.flh = flh;
    }

    public String getNd() {
        return nd;
    }

    public void setNd(String nd) {
        this.nd = nd;
    }

    public Date getQrq() {
        return qrq;
    }

    public void setQrq(Date qrq) {
        this.qrq = qrq;
    }

    public Date getZrq() {
        return zrq;
    }

    public void setZrq(Date zrq) {
        this.zrq = zrq;
    }

    public Integer getJs() {
        return js;
    }

    public void setJs(Integer js) {
        this.js = js;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }

    public String getBgqx() {
        return bgqx;
    }

    public void setBgqx(String bgqx) {
        this.bgqx = StringUtils.trim(bgqx);
    }

    public String getMj() {
        return mj;
    }

    public void setMj(String mj) {
        this.mj = StringUtils.trim(mj);
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getCfwz() {
        return cfwz;
    }

    public void setCfwz(String cfwz) {
        this.cfwz = cfwz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getGdsj() {
        return gdsj;
    }

    public void setGdsj(Date gdsj) {
        this.gdsj = gdsj;
    }

    public String getResourceId() {
        return resourceId;
    }

    public void setResourceId(String resourceId) {
        this.resourceId = resourceId;
    }

    public int getState() {
        return state;
    }

    public void setState(int state) {
        this.state = state;
    }

    public String getSqrq() {
        return sqrq;
    }

    public void setSqrq(String sqrq) {
        this.sqrq = sqrq;
    }

    public String getSzrq() {
        return szrq;
    }

    public void setSzrq(String szrq) {
        this.szrq = szrq;
    }

    public Boolean getHasOriginal() {
        return hasOriginal;
    }

    public void setHasOriginal(Boolean hasOriginal) {
        this.hasOriginal = hasOriginal;
    }

    public static boolean isArchiveModelName(String modelName) {
        return !modelName.endsWith(Archive.DOCUMENT_SUFFIX) && !Document.MODEL_NAME.endsWith(modelName);
    }

    public static String toDocumentModelName(String archiveModelName) {
        if (archiveModelName.endsWith(Archive.DOCUMENT_SUFFIX)) {
            return archiveModelName;
        } else if (Archive.MODEL_NAME.equals(archiveModelName) || Document.MODEL_NAME.equals(archiveModelName)) {
            return Document.MODEL_NAME;
        } else {
            return archiveModelName + Archive.DOCUMENT_SUFFIX;
        }
    }
}
